import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = 'https://gist.githubusercontent.com/amiralitah/9f8d0f78af31e1f54e7b2069af075211/raw/2ad41ec7d2190864d686ff1909ffa96ff9c68e99/breast_cancer.csv';
const parseRow = (d) => {
  d.radius_se = +d.radius_se;
  d.texture_se = +d.texture_se;
  d.perimeter_se = +d.perimeter_se;
  d.area_se = +d.area_se;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.perimeter_se;
const yValue = (d) => d.area_se;
const rxValue = (d) => d.radius_se;
const ryValue = (d) => d.texture_se;
const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = 'species';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.area_se);
  const y = yValue((d) => d.radius_se);
  const marker = (d) => {
        	switch(d){
            case 'stage one':
              return 'orange';
            case 'stage two':
              return 'blue';
            default:
              return 'black';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.area_se),
          y: yValue((d) => d.radius_se),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.area_se)
    .yValue((d) => d.radius_se)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'area_se',
    'texture_se',
    'perimeter_se',
    'radius_se',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'area_se',
    'texture_se',
    'perimeter_se',
    'radius_se'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Breast Cancer").style("font-size", "35px").attr("alignment-baseline","middle")

   
// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("stage one").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("stage two").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("stage three").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("radius_se");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "orange")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "blue")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "black")
   // plot area_se on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("area_se");
     // plot texture_se on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("texture_se");
     // plot perimeter_se on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("perimeter_se");
     // plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("radius_se");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();



